@@ -1,6 +1,7 @@
 import re
 import json
 import inspect
+import sys
 from funcy import memoize, compose, wraps, any, any_fn, select_values, mapcat
 
 from django.db import models
@@ -143,7 +144,9 @@ import hashlib
 
 class md5:
     def __init__(self, s=None):
-        self.md5 = hashlib.md5()
+        # set usedforsecurity for FIPS compliance
+        kwargs = {'usedforsecurity': False} if sys.version_info >= (3, 9) else {}
+        self.md5 = hashlib.md5(**kwargs)
         if s is not None:
             self.update(s)
 
