@@ -730,6 +730,10 @@ class IssueTests(BaseTestCase):
             conditions.append(reduce(operator.or_, queries))
         list(queryset.filter(reduce(operator.and_, conditions)).cache())
 
+    @unittest.skipIf(connection.vendor != 'postgresql', "Only for PostgreSQL")
+    def test_489(self):
+        TaggedPost.objects.cache().filter(tags=[]).count()
+
 
 class RelatedTests(BaseTestCase):
     fixtures = ['basic']
